Functions
- router
- Build the node HTTP router by delegating to the shared
posemesh-node-registrationrouter. This ensures that the registration callback persists the node secret and that DDS health probes update the registration health state in a single, canonical store used by the outbound registration loop.